<?php
/**
 * Header template for our theme
 *
 * Displays all of the <head> section and everything up till <div id="main">.
 *
 * @package WordPress
 * @subpackage Twenty_Ten
 * @since Twenty Ten 1.0
 */
?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta name="viewport" content="width=device-width, initial-scale=1, user-scalable=no, minimal-ui">
<meta charset="<?php bloginfo( 'charset' ); ?>" />
<title><?php
	/*
	 * Print the <title> tag based on what is being viewed.
	 */
	global $page, $paged;

	wp_title( '|', true, 'right' );

	// Add the blog name.
	bloginfo( 'name' );

	// Add the blog description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		echo " | $site_description";

	// Add a page number if necessary:
	if ( ( $paged >= 2 || $page >= 2 ) && ! is_404() )
		echo esc_html( ' | ' . sprintf( __( 'Page %s', 'twentyten' ), max( $paged, $page ) ) );

	?></title>
<link rel="profile" href="http://gmpg.org/xfn/11" />
<link href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.6/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-1q8mTJOASx8j1Au+a5WDVnPi2lkFfwwEAa8hDDdjZlpLegxhjVME1fgjWPGmkzs7" crossorigin="anonymous">
<link rel="stylesheet" type="text/css" media="all" href="<?php bloginfo( 'stylesheet_url' ); ?>" />
<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>" />
<?php
	/*
	 * We add some JavaScript to pages with the comment form
	 * to support sites with threaded comments (when in use).
	 */
	if ( is_singular() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );

	/*
	 * Always have wp_head() just before the closing </head>
	 * tag of your theme, or you will break many plugins, which
	 * generally use this hook to add elements to <head> such
	 * as styles, scripts, and meta tags.
	 */
	wp_head();
?>
</head>

<body <?php body_class(); ?>>

<div class="header">
	<div class="container">
		<div class="row">
			<div class="col-sm-3 logo">
				<a href="/">
					<img src="<?php echo IMG_PATH; ?>/logo.png" class="img-responsive" alt="logo"/>
				</a>
			</div>
			<div class="col-sm-3 pull-right">
				<div class="right-nav text-center">
					<div class="row">
						<div class="col-xs-9 col-sm-12 hidden-xs">
							<button class="btn btn-default btn-client">CLIENT LOGIN</button>
						</div>
						<div class="col-sm-12">
							<div class="row">
								<div class="col-xs-5 col-sm-12">
									<a class="tel" href="tel:07717 661596">07717 661596</a>
								</div>
								<div class="col-xs-7 col-sm-12">
									<a class="email" href="mailto:office@inferenergy.co.uk">office@inferenergy.co.uk</a>
								</div>
							</div>
							<div class="col-xs-12 visible-xs border-top"></div>
						</div>
						<div class="col-xs-3 visible-xs">
							<button class="btn btn-infer btn-block" type="button" data-toggle="collapse" data-target="#mobileNav" aria-expanded="false" aria-controls="mobileNav">
								<span class="glyphicon glyphicon-menu-hamburger"></span>
							</button>
						</div>
						<div class="col-xs-9 col-sm-12 visible-xs">
							<button class="btn btn-default btn-client">CLIENT LOGIN</button>
						</div>
					</div>
				</div>
			</div>
			<div class="col-xs-12 visible-xs">
				<div class="collapse" id="mobileNav">
					<?php 
						$menu_name = 'primary';
						$actual_link = "http://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";
						if ( ( $locations = get_nav_menu_locations() ) && isset( $locations[ $menu_name ] ) ) {
						    $menu = wp_get_nav_menu_object( $locations[ $menu_name ] );
						    $menu_items = wp_get_nav_menu_items($menu->term_id);
						 	echo "<ul class='mobile-nav'>";
							foreach ((array)$menu_items as $key => $menu_item){
								$active = $actual_link == $menu_item->url ? "active" : "";
								$html = array();
								if (!$menu_item->menu_item_parent){
									foreach ((array)$menu_items as $key => $sub_menu_item){
										$subactive = $actual_link == $sub_menu_item->url ? "active" : "";
									    if ($sub_menu_item->menu_item_parent == $menu_item->db_id) {
									    	$html[] = "<li class='$subactive'><a href='".$sub_menu_item->url."'><span class='orange'>/</span> &nbsp; ". strtoupper($sub_menu_item->title)."</li>";
									    }
									}
									if (empty($html)) {
										echo "<li class='$active$subactive'><a href='".$menu_item->url."'><span class='orange'>/</span> &nbsp; ". strtoupper($menu_item->title)."</a>";
									}
									else {
										echo "<li class='$active$gsubactive'>";
										echo "<a role='button' data-toggle='collapse' href='#".str_replace(' ', '', $menu_item->title)."' aria-expanded='false' aria-controls='".str_replace(' ', '', $menu_item->title)."'>";
										echo "<span class='orange'>/</span> &nbsp; ".$gsubactive.strtoupper($menu_item->title)."</a>";
									}
								}
								if (!empty($html)) echo "<ul class='collapse' id='".str_replace(' ', '', $menu_item->title)."'>".implode($html, '')."</ul>";
								echo "</li>";
							}
							echo "</ul>";
						}
					?>
				</div>
			</div>
			<div class="col-sm-6 pull-left text-center hidden-xs">
				<?php 
					$menu_name = 'primary';
					$actual_link = "http://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";
					if ( ( $locations = get_nav_menu_locations() ) && isset( $locations[ $menu_name ] ) ) {
					    $menu = wp_get_nav_menu_object( $locations[ $menu_name ] );
					    $menu_items = wp_get_nav_menu_items($menu->term_id);
					 	echo "<ul class='mid-nav'>";
						foreach ((array)$menu_items as $key => $menu_item){
							$active = $actual_link == $menu_item->url ? "active" : "";
							$is_last = $key == count($menu_items)-1;
							$suffix = '<span class="orange">/</span>';
							$html = array();
							if (!$menu_item->menu_item_parent){
								foreach ((array)$menu_items as $key => $sub_menu_item){
									$subactive = $actual_link == $sub_menu_item->url ? "active" : "";
								    if ($sub_menu_item->menu_item_parent == $menu_item->db_id) $html[] = "<li class='$subactive'><a href='".$sub_menu_item->url."'>". strtoupper($sub_menu_item->title)." <span class='active'><span class='orange'>></span></span></a></li>";
								}
								if (empty($html)) echo "<li class='$active$subactive'><a href='".$menu_item->url."' ".$no_instant.">". strtoupper($menu_item->title).($is_last?"":$suffix)."</a>";
								else echo "<li class='$active$gsubactive'><a href='".$menu_item->url."'>".$gsubactive.strtoupper($menu_item->title).($is_last?"":$suffix). "</a>";
							}
							if (!empty($html)) echo "<ul>" .$arrow.implode($html, '') . "</ul>";
							echo "</li>";
						}
						echo "</ul>";
					}
				?>
			</div>
		</div>
	</div>
</div>

